@@ -1,15 +1,17 @@
 package main
 
 import (
-	"sort"
 	"testing"
 )
 
 func TestDropAmbiguousPkgs(t *testing.T) {
 	pkgs := []string{
 		"bar",
+		"bar",
+		"baz",
 		"baz:arm64",
 		"foo",
+		"foo",
 		"foo:amd64",
 		"foo:i386",
 	}
@@ -19,13 +21,12 @@ func TestDropAmbiguousPkgs(t *testing.T) {
 		"foo:amd64",
 		"foo:i386",
 	}
-	got := dropAmbiguousPkgs(pkgs)
-	sort.StringSlice(got).Sort()
+	got := uniqArchFreePkgs(pkgs)
 
 	// TODO: use cmp.Diff instead.
 	equal := len(got) == len(want)
 	if equal {
-		for i := range len(got) {
+		for i := range got {
 			if got[i] != want[i] {
 				equal = false
 				break
